changeset 16883:d1d4d81f9ece

Change all uses of win95, winnt, and win32 into Windows 95, Windows NT, and W32, respectively. Expand "win" substring in variables referring to Microsoft Windows constructs into "windows". Canonicalize header comments to use same terminology.
author Geoff Voelker <voelker@cs.washington.edu>
date Mon, 20 Jan 1997 00:34:34 +0000
parents edebdaa8e499
children 36babc489b0c
files src/w32console.c
diffstat 1 files changed, 3 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/src/w32console.c	Mon Jan 20 00:05:31 1997 +0000
+++ b/src/w32console.c	Mon Jan 20 00:34:34 1997 +0000
@@ -1,4 +1,4 @@
 /* Terminal hooks for Windows NT port of GNU Emacs.
    Copyright (C) 1992 Free Software Foundation, Inc.
 
 This file is part of GNU Emacs.
@@ -492,7 +492,7 @@
 
       SetConsoleActiveScreenBuffer (cur_screen);
 
-      /* make cursor big and visible (100 on Win95 makes it disappear)  */
+      /* make cursor big and visible (100 on Windows 95 makes it disappear)  */
       cci.dwSize = 99;
       cci.bVisible = TRUE;
       (void) SetConsoleCursorInfo (cur_screen, &cci);
@@ -539,7 +539,7 @@
 typedef int (*term_hook) ();
 
 void
-initialize_win_nt_display (void)
+initialize_w32_display (void)
 {
   CONSOLE_SCREEN_BUFFER_INFO	info;
@@ -1,4 +1,4 @@
-/* Terminal hooks for Windows NT port of GNU Emacs.
+/* Terminal hooks for GNU Emacs on the Microsoft W32 API.
    Copyright (C) 1992 Free Software Foundation, Inc.
 